==> pyroasts-1.0.2.tar.gz: pyroasts-1.0.2/README.md <==
![Python build & test](https://github.com/software-students-fall2024/3-python-package-all-stars-v3/actions/workflows/build.yaml/badge.svg)

# Python Roast Package 

## Description

- Our project is a Python package that generates light-hearted 'roasts', insults, directed to the user. The package contains different types of roast that the user can pick and generate.

## Link to package

- This is the Link to the our group's package page: [pyroasts](https://pypi.org/project/pyroasts/)

## How to install and use this package

1. Create a `pipenv`-managed virtual environment and install the latest version of our package installed: `pipenv install pyroasts`.
2. Activate the virtual environment: `pipenv shell`.
3. Create a Python program file that imports your package and uses it, e.g. from `pyroasts import *` and then `print(get_roast())` (replace `get_roast()`with any function that exists in our package) .
4. Run the program: `python3 my_program_filename.py`.
5. Exit the virtual environment: exit.

[Here are some coding examples:](https://onedrive.live.com/?redeem=aHR0cHM6Ly8xZHJ2Lm1zL3UvYy8yZGMyOGJkODhiNWFiOTdhL0VWajBhaTlUWW1sS29Fdi1Ka2sxV3Q0QmkzVXVwZ0NvREhOWkllUXdnc3ZXaXc%5FZT1oUlJVQ08&cid=2DC28BD88B5AB97A&id=2DC28BD88B5AB97A%21s2f6af45862534a69a04bfe2649355ade&parId=2DC28BD88B5AB97A%21286&o=OneUp)

## How to set up the virtual environment, install dependencies, and build and test our package

1. If you haven't already, install `pipenv` using the command: `pip install pipenv`
2. Install all the dependencies listed in the `Pipfile`: `pipenv install`
3. Activate the virtual environment: `pipenv shell`.
4. Run all the tests: `pytest` or `python3 -m pytest`.
5. Exit the virtual environment


## Teammates

Links to all the member's Github accounts:
- https://github.com/ianpompliano
- https://github.com/sanskritig08
- https://github.com/ocnwaokoro
- https://github.com/mtodorovic27

==> pyroasts-1.0.3.tar.gz: pyroasts-1.0.3/README.md <==
![Python build & test](https://github.com/software-students-fall2024/3-python-package-all-stars-v3/actions/workflows/build.yaml/badge.svg)

# Python Roast Package 

## Description

- Our project is a Python package that generates light-hearted 'roasts', insults, directed to the user. The package contains different types of roast that the user can pick and generate.

## Link to package

- This is the Link to the our group's package page: [pyroasts](https://pypi.org/project/pyroasts/)

## How to install and use this package

1. Create a `pipenv`-managed virtual environment and install the latest version of our package installed: `pipenv install pyroasts`.
2. Activate the virtual environment: `pipenv shell`.
3. Create a Python program file that imports your package and uses it, e.g. from `pyroasts import *` and then `print(get_roast())` (replace `get_roast()`with any function that exists in our package) .
4. Run the program: `python3 my_program_filename.py`.
5. Exit the virtual environment: exit.

[Here are some coding examples:](https://1drv.ms/u/c/2dc28bd88b5ab97a/EVj0ai9TYmlKoEv-Jkk1Wt4BaBvNijzNNT_uA2HD72_FcQ?e=z12wC0)

## How to set up the virtual environment, install dependencies, and build and test our package

1. If you haven't already, install `pipenv` using the command: `pip install pipenv`
2. Install all the dependencies listed in the `Pipfile`: `pipenv install`
3. Activate the virtual environment: `pipenv shell`.
4. Run all the tests: `pytest` or `python3 -m pytest`.
5. Exit the virtual environment


## Teammates

Links to all the member's Github accounts:
- https://github.com/ianpompliano
- https://github.com/sanskritig08
- https://github.com/ocnwaokoro
- https://github.com/mtodorovic27
